pub struct BudgetEnvelope {
pub session_id: String,
pub max_steps: Option<u32>,
pub steps_used: u32,
pub max_revisions: Option<u32>,
pub revisions_used: u32,
pub max_cost_usd: Option<f64>,
pub cost_used_usd: f64,
}Expand description
Budget envelope for plan execution.
Tracks cost, step, and revision budgets for a session. The governance layer checks these limits before allowing further execution.
Fields
session_id: StringSession ID.
max_steps: Option<u32>Maximum number of node execution steps allowed.
steps_used: u32Steps consumed so far.
max_revisions: Option<u32>Maximum number of plan revisions allowed.
revisions_used: u32Revisions consumed so far.
max_cost_usd: Option<f64>Maximum total cost in USD.
cost_used_usd: f64Cost consumed so far.
Implementations
Sourceimpl BudgetEnvelope
impl BudgetEnvelope
Sourcepub fn new(session_id: impl Into<String>) -> BudgetEnvelope
pub fn new(session_id: impl Into<String>) -> BudgetEnvelope
Create a new budget envelope with no limits.
Sourcepub fn steps_exhausted(&self) -> bool
pub fn steps_exhausted(&self) -> bool
Whether the step budget is exhausted.
Sourcepub fn revisions_exhausted(&self) -> bool
pub fn revisions_exhausted(&self) -> bool
Whether the revision budget is exhausted.
Sourcepub fn cost_exhausted(&self) -> bool
pub fn cost_exhausted(&self) -> bool
Whether the cost budget is exhausted.
Sourcepub fn any_exhausted(&self) -> bool
pub fn any_exhausted(&self) -> bool
Whether any budget limit has been exceeded.
Sourcepub fn record_step(&mut self)
pub fn record_step(&mut self)
Record a step.
Sourcepub fn record_revision(&mut self)
pub fn record_revision(&mut self)
Record a plan revision.
Sourcepub fn record_cost(&mut self, usd: f64)
pub fn record_cost(&mut self, usd: f64)
Record cost.